==> kubernetes-model-storageclass-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/storage/TokenRequestFluentImpl.java <==
package io.fabric8.kubernetes.api.model.storage;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class TokenRequestFluentImpl<A extends io.fabric8.kubernetes.api.model.storage.TokenRequestFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.storage.TokenRequestFluent<A>{
  public TokenRequestFluentImpl() {
  }
  public TokenRequestFluentImpl(io.fabric8.kubernetes.api.model.storage.TokenRequest instance) {
    this.withAudience(instance.getAudience()); 
    this.withExpirationSeconds(instance.getExpirationSeconds()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String audience;
  private java.lang.Long expirationSeconds;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getAudience() {
    return this.audience;
  }
  public A withAudience(java.lang.String audience) {
    this.audience=audience; return (A) this;
  }
  public java.lang.Boolean hasAudience() {
    return this.audience != null;
  }
  
  /**
   * Method is deprecated. use withAudience instead.
   */
  @java.lang.Deprecated
  public A withNewAudience(java.lang.String arg0) {
    return (A)withAudience(new String(arg0));
  }
  public java.lang.Long getExpirationSeconds() {
    return this.expirationSeconds;
  }
  public A withExpirationSeconds(java.lang.Long expirationSeconds) {
    this.expirationSeconds=expirationSeconds; return (A) this;
  }
  public java.lang.Boolean hasExpirationSeconds() {
    return this.expirationSeconds != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TokenRequestFluentImpl that = (TokenRequestFluentImpl) o;
    if (audience != null ? !audience.equals(that.audience) :that.audience != null) return false;
    if (expirationSeconds != null ? !expirationSeconds.equals(that.expirationSeconds) :that.expirationSeconds != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(audience,  expirationSeconds,  additionalProperties,  super.hashCode());
  }
  
}

==> kubernetes-model-storageclass-5.12.0-sources.jar: io/fabric8/kubernetes/api/model/storage/TokenRequestFluentImpl.java <==
package io.fabric8.kubernetes.api.model.storage;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class TokenRequestFluentImpl<A extends io.fabric8.kubernetes.api.model.storage.TokenRequestFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.storage.TokenRequestFluent<A>{
  public TokenRequestFluentImpl() {
  }
  public TokenRequestFluentImpl(io.fabric8.kubernetes.api.model.storage.TokenRequest instance) {
    this.withAudience(instance.getAudience()); 
    this.withExpirationSeconds(instance.getExpirationSeconds()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String audience;
  private java.lang.Long expirationSeconds;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getAudience() {
    return this.audience;
  }
  public A withAudience(java.lang.String audience) {
    this.audience=audience; return (A) this;
  }
  public java.lang.Boolean hasAudience() {
    return this.audience != null;
  }
  
  /**
   * Method is deprecated. use withAudience instead.
   */
  @java.lang.Deprecated
  public A withNewAudience(java.lang.String arg0) {
    return (A)withAudience(new String(arg0));
  }
  public java.lang.Long getExpirationSeconds() {
    return this.expirationSeconds;
  }
  public A withExpirationSeconds(java.lang.Long expirationSeconds) {
    this.expirationSeconds=expirationSeconds; return (A) this;
  }
  public java.lang.Boolean hasExpirationSeconds() {
    return this.expirationSeconds != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TokenRequestFluentImpl that = (TokenRequestFluentImpl) o;
    if (audience != null ? !audience.equals(that.audience) :that.audience != null) return false;
    if (expirationSeconds != null ? !expirationSeconds.equals(that.expirationSeconds) :that.expirationSeconds != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(audience,  expirationSeconds,  additionalProperties,  super.hashCode());
  }
  
}
